.highlight {
    padding-top: 10px;
    margin-bottom: 10px;
}

p code{
    padding : 5px;
}
.highlighttable .copybtn , .highlighttable .filename , .highlight .copybtn , .highlight .filename,.highlighttable tr , .highlight pre{
    padding-left: 10px;
    padding-right: 10px;
}
.highlighttable tr , .highlight pre{
    padding-top:10px;
    padding-bottom: 10px;
}


img{
    width : 100%;
}

.img-structure{
    width: auto;
}

details > details,
details > div {
  padding-left: 16px;
}

blockquote{
    position:relative;
    border-left:3px solid #c0c0c0;
    padding-left:10px;
}
blockquote:before{
    font-family:bootstrap-icons;
    content:'\F6B0';
    color:rgb(139, 139, 139);
}
blockquote p{
    position:relative;
}
blockquote cite{
    display: block;
    font-size:0.8rem;
    color:#F8C8B2;
    text-align:right;
}

a[target="_blank"]:after{
    font-family:bootstrap-icons;
    content:'\F143';
    font-size:0.7rem;
}

svg{
    width: 100%;
}

.alert-heading:before{
    font-family:bootstrap-icons;
    padding-right: 0.25em;
    font-size: 15px;
}

.note .alert-heading:before{
    content:'\F26A';
}
.abstract .alert-heading:before{
    content:'\F3B8';
}
.info .alert-heading:before{
    content:'\F430';
}
.tip .alert-heading:before{
    content:'\F468';
}
.success .alert-heading:before{
    content:'\F272';
}
.question .alert-heading:before{
    content:'\F504';
}
.warning .alert-heading:before{
    content:'\F33A';
}
.failure .alert-heading:before{
    content:'\F622';
}
.danger .alert-heading:before{
    content:'\F67B';
}
.bug .alert-heading:before{
    content:'\F1DB';
}
.example .alert-heading:before{
    content:'\F41F';
}

@media print{
    .print-visible{
        display: none;
    }
    .print-hide{
        display: none;
    }
    .print-block{
        display: none;
    }
    .print-main{
        width: 100%;
    }
}

a{
    text-decoration: none;
}


@media (prefers-color-scheme: dark) {
    a{
        color:385898;
    }
    .highlighttable , .highlight{
        background: #404040;
    }
    code , .highlighttable tr , .highlight pre{
        color : #e1e1e1;
        background : #2f2f2f !important;
    }
    .highlight{
        border: solid 0.5px #404040;
    }
  }
  
  @media (prefers-color-scheme: light) {
    a{
        color:0066CC;
    }
    .highlighttable , .highlight{
        background: #e6e6e6;
    }
    code , .highlighttable tr , .highlight pre{
        color : #171717;
        background : #f2f2f2 !important;
    }
    .highlight{
        border: solid 0.5px #e6e6e6;
    }
  }